@@ -1,28 +1,31 @@
-import math
-import random
 from typing import List
 
 
-class adaptive:
+class Adaptive:
     """Implements sampling to achieve the effect of a uniform random sample."""
 
-    sample_array: List[float] = []
-    current_index = 0
-    total_samples = 0
-    max_samples = 0
-    count_average = 0
-    sum_average = 0
-    max_average = 1
-
     def __init__(self, size: int):
+        # size must be a power of two
         self.max_samples = size
-        # must be a power of two
-        self.sample_array = [0] * size
+        self.current_index = 0
+        self.sample_array = [0.0] * size
+
+    def __add__(self: "Adaptive", other: "Adaptive") -> "Adaptive":
+        n = Adaptive(self.max_samples)
+        for i in range(0, self.max_samples):
+            n.sample_array[i] = self.sample_array[i] + other.sample_array[i]
+        n.current_index = max(self.current_index, other.current_index)
+        return n
+
+    def __iadd__(self: "Adaptive", other: "Adaptive") -> "Adaptive":
+        for i in range(0, self.max_samples):
+            self.sample_array[i] += other.sample_array[i]
+        self.current_index = max(self.current_index, other.current_index)
+        return self
 
     def add(self, value: float) -> None:
         if self.current_index >= self.max_samples:
             # Decimate
-            # print("DECIMATION " + str(self.sample_array))
             new_array = [0.0] * self.max_samples
             for i in range(0, self.max_samples // 3):
                 arr = [self.sample_array[i * 3 + j] for j in range(0, 3)]
@@ -30,11 +33,8 @@ class adaptive:
                 new_array[i] = arr[1]  # Median
             self.current_index = self.max_samples // 3
             self.sample_array = new_array
-            # print("POST DECIMATION = " + str(self.sample_array))
-            # Update average length
-            self.max_average *= 3
         self.sample_array[self.current_index] = value
-        self.current_index += 1  # count_average += 1
+        self.current_index += 1
 
     def get(self) -> List[float]:
         return self.sample_array
