@@ -11,7 +11,6 @@ class ScaleneGPU:
     def __init__(self) -> None:
         self.__ngpus = 0
         self.__has_gpu = False
-        self.__handle = []
         self.__pid = os.getpid()
         self.__has_per_pid_accounting = False
         with contextlib.suppress(Exception):
@@ -19,14 +18,16 @@ class ScaleneGPU:
             # Try to actually get utilization and memory usage.
             # If this fails, we disable GPU profiling.
             self.__ngpus = pynvml.nvmlDeviceGetCount()
-            for i in range(self.__ngpus):
-                handle = pynvml.nvmlDeviceGetHandleByIndex(i)
-                self.__handle.append(handle)
+            self.__handle = [
+                pynvml.nvmlDeviceGetHandleByIndex(i)
+                for i in range(self.__ngpus)
+            ]
             self.__has_per_pid_accounting = self._set_accounting_mode()
-            total_load = self.gpu_utilization(self.__pid)
-            mem_used = self.gpu_memory_usage(self.__pid)
+            self.gpu_utilization(self.__pid)
+            self.gpu_memory_usage(self.__pid)
             # If we make it this far, everything is working, so we can profile GPU usage.
-            self.__has_gpu = True
+            # Handle the case when GPUs are disabled. See https://github.com/plasma-umass/scalene/issues/536.
+            self.__has_gpu = self.__ngpus > 0
 
     def disable(self) -> None:
         """Turn off GPU accounting."""
@@ -83,7 +84,11 @@ class ScaleneGPU:
                         h, pid
                     ).gpuUtilization
             else:
-                utilization += pynvml.nvmlDeviceGetUtilizationRates(h).gpu
+                try:
+                    utilization += pynvml.nvmlDeviceGetUtilizationRates(h).gpu
+                except pynvml.nvml.NVMLError_Unknown:
+                    # Silently ignore NVML errors. "Fixes" https://github.com/plasma-umass/scalene/issues/471.
+                    pass
         return (utilization / ngpus) / 100.0
 
     def has_gpu(self) -> bool:
@@ -111,12 +116,15 @@ class ScaleneGPU:
         total_used_GPU_memory = 0
         for i in range(self.__ngpus):
             handle = self.__handle[i]
-            for proc in pynvml.nvmlDeviceGetComputeRunningProcesses(handle):
-                # Only accumulate memory stats for the current pid.
-                if proc.usedGpuMemory and proc.pid == pid:
-                    # First check is to protect against return of None
-                    # from incompatible NVIDIA drivers.
-                    total_used_GPU_memory += proc.usedGpuMemory / 1048576
+            with contextlib.suppress(Exception):
+                for proc in pynvml.nvmlDeviceGetComputeRunningProcesses(
+                    handle
+                ):
+                    # Only accumulate memory stats for the current pid.
+                    if proc.usedGpuMemory and proc.pid == pid:
+                        # First check is to protect against return of None
+                        # from incompatible NVIDIA drivers.
+                        total_used_GPU_memory += proc.usedGpuMemory / 1048576
         return total_used_GPU_memory
 
     def get_stats(self) -> Tuple[float, float]:
