@@ -2,16 +2,16 @@ import copy
 import os
 import random
 import re
-import statistics
 import sys
 
 from collections import OrderedDict, defaultdict
 from operator import itemgetter
 from pathlib import Path
-from typing import Any, Callable, Dict, List
+from typing import Any, Callable, Dict, List, Optional
 
 from scalene.scalene_leak_analysis import ScaleneLeakAnalysis
 from scalene.scalene_statistics import Filename, LineNumber, ScaleneStatistics
+from scalene.scalene_analysis import ScaleneAnalysis
 
 if sys.platform != "win32":
     from scalene.crdp import rdp
@@ -69,7 +69,7 @@ class ScaleneJSON:
 
     def compress_samples(
         self, samples: List[Any], max_footprint: float
-    ) -> List[Any]:
+    ) -> Any:
         if len(samples) <= self.max_sparkline_samples:
             return samples
         # Try to reduce the number of samples with the
@@ -87,8 +87,7 @@ class ScaleneJSON:
             new_samples = sorted(
                 random.sample(new_samples, self.max_sparkline_samples)
             )
-        samples = new_samples
-        return samples
+        return new_samples
 
     # Profile output methods
     def output_profile_line(
@@ -105,10 +104,28 @@ class ScaleneJSON:
     ) -> Dict[str, Any]:
         """Print at most one line of the profile (true == printed one)."""
 
-        full_fname = os.path.abspath(fname)
-
         if not force_print and not profile_this_code(fname, line_no):
-            return {}
+            return {
+                "lineno": line_no,
+                "line": line,
+                "n_core_utilization": 0,
+                "n_cpu_percent_c": 0,
+                "n_cpu_percent_python": 0,
+                "n_sys_percent": 0,
+                "n_gpu_percent": 0,
+                "n_gpu_avg_memory_mb": 0,
+                "n_gpu_peak_memory_mb": 0,
+                "n_peak_mb": 0,
+                "n_growth_mb": 0,
+                "n_avg_mb": 0,
+                "n_mallocs": 0,
+                "n_malloc_mb": 0,
+                "n_usage_fraction": 0,
+                "n_python_fraction": 0,
+                "n_copy_mb_s": 0,
+                "memory_samples": [],
+            }
+
         # Prepare output values.
         n_cpu_samples_c = stats.cpu_samples_c[fname][line_no]
         # Correct for negative CPU sample counts. This can happen
@@ -171,6 +188,7 @@ class ScaleneJSON:
 
         # Adjust CPU time by utilization.
         mean_cpu_util = stats.cpu_utilization[fname][line_no].mean()
+        mean_core_util = stats.core_utilization[fname][line_no].mean()
         n_sys_percent = n_cpu_percent * (1.0 - mean_cpu_util)
         n_cpu_percent_python *= mean_cpu_util
         n_cpu_percent_c *= mean_cpu_util
@@ -192,12 +210,13 @@ class ScaleneJSON:
         return {
             "lineno": line_no,
             "line": line,
+            "n_core_utilization": mean_core_util,
             "n_cpu_percent_c": n_cpu_percent_c,
             "n_cpu_percent_python": n_cpu_percent_python,
             "n_sys_percent": n_sys_percent,
             "n_gpu_percent": n_gpu_percent,
-            "n_gpu_avg_memory_mb": n_gpu_mem_samples.mean() / 1048576,
-            "n_gpu_peak_memory_mb": n_gpu_mem_samples.peak() / 1048576,
+            "n_gpu_avg_memory_mb": n_gpu_mem_samples.mean(),
+            "n_gpu_peak_memory_mb": n_gpu_mem_samples.peak(),
             "n_peak_mb": n_peak_mb,
             "n_growth_mb": n_peak_mb,  # For backwards compatibility
             "n_avg_mb": n_avg_mb,
@@ -216,7 +235,9 @@ class ScaleneJSON:
         pid: int,
         profile_this_code: Callable[[Filename, LineNumber], bool],
         python_alias_dir: Path,
-        program_path: Path,
+        program_path: Filename,
+        entrypoint_dir: Filename,
+        program_args: Optional[List[str]],
         profile_memory: bool = True,
         reduced_profile: bool = False,
     ) -> Dict[str, Any]:
@@ -260,8 +281,23 @@ class ScaleneJSON:
         else:
             stats.memory_footprint_samples = []
 
+        # Adjust the program name if it was a Jupyter cell.
+        result = re.match(r"_ipython-input-([0-9]+)-.*", program)
+        if result:
+            program = Filename("[" + result.group(1) + "]")
+
+        # Convert stacks into a representation suitable for JSON dumping.
+        stks = []
+        for stk in stats.stacks.keys():
+            this_stk: List[str] = []
+            this_stk.extend(stk)
+            stks.append((this_stk, stats.stacks[stk]))
+
         output: Dict[str, Any] = {
             "program": program,
+            "entrypoint_dir": entrypoint_dir,
+            "args": program_args,
+            "filename": program_path,
             "alloc_samples": stats.alloc_samples,
             "elapsed_time_sec": stats.elapsed_time,
             "growth_rate": growth_rate,
@@ -276,6 +312,7 @@ class ScaleneJSON:
             "gpu": self.gpu,
             "memory": profile_memory,
             "samples": stats.memory_footprint_samples,
+            "stacks": stks,
         }
 
         # Build a list of files we will actually report on.
@@ -288,7 +325,10 @@ class ScaleneJSON:
             fname = Filename(fname)
             try:
                 percent_cpu_time = (
-                    100 * stats.cpu_samples[fname] / stats.total_cpu_samples
+                    100
+                    * stats.cpu_samples[fname]
+                    / stats.elapsed_time
+                    # 100 * stats.cpu_samples[fname] / stats.total_cpu_samples
                 )
             except ZeroDivisionError:
                 percent_cpu_time = 0
@@ -306,7 +346,7 @@ class ScaleneJSON:
         # Instead, write info to disk for the main process to collect.
         if pid:
             stats.output_stats(pid, python_alias_dir)
-            # Return a value to indicate that the stats were successfully 
+            # Return a value to indicate that the stats were successfully
             # output to the proper directory
             return {"is_child": True}
 
@@ -319,7 +359,7 @@ class ScaleneJSON:
             # restore its name, as in "[12]".
             fname_print = fname
 
-            result = re.match(r"ipython-input-([0-9]+)-.*", fname_print)
+            result = re.match(r"_ipython-input-([0-9]+)-.*", fname_print)
             if result:
                 fname_print = Filename("[" + result.group(1) + "]")
 
@@ -365,19 +405,33 @@ class ScaleneJSON:
                 )
 
             # Print out the the profile for the source, line by line.
-            full_fname = os.path.normpath(os.path.join(program_path, fname))
+            full_fname = fname
             try:
-                with open(full_fname, "r") as source_file:
+                with open(full_fname, "r", encoding="utf-8") as source_file:
                     code_lines = source_file.readlines()
+
             except (FileNotFoundError, OSError):
                 continue
+            # Find all enclosing regions (loops or function defs) for each line of code.
+
+            code_str = "".join(code_lines)
+
+            enclosing_regions = ScaleneAnalysis.find_regions(code_str)
+            outer_loop = ScaleneAnalysis.find_outermost_loop(code_str)
+            imports = ScaleneAnalysis.get_native_imported_modules(code_str)
 
             output["files"][fname_print] = {
                 "percent_cpu_time": percent_cpu_time,
                 "lines": [],
                 "leaks": reported_leaks,
+                "imports": imports,
             }
             for lineno, line in enumerate(code_lines, start=1):
+                # Protect against JS 'injection' in Python comments by replacing some characters with Unicode.
+                # This gets unescaped in scalene-gui.js.
+                line = line.replace("&", "\\u0026")
+                line = line.replace("<", "\\u003c")
+                line = line.replace(">", "\\u003e")
                 profile_line = self.output_profile_line(
                     fname=fname,
                     fname_print=fname_print,
@@ -389,6 +443,16 @@ class ScaleneJSON:
                     force_print=False,
                 )
                 if profile_line:
+                    profile_line["start_region_line"] = enclosing_regions[
+                        lineno
+                    ][0]
+                    profile_line["end_region_line"] = enclosing_regions[
+                        lineno
+                    ][1]
+                    profile_line["start_outermost_loop"] = outer_loop[lineno][
+                        0
+                    ]
+                    profile_line["end_outermost_loop"] = outer_loop[lineno][1]
                     # When reduced-profile set, only output if the payload for the line is non-zero.
                     if reduced_profile:
                         profile_line_copy = copy.copy(profile_line)
@@ -396,9 +460,7 @@ class ScaleneJSON:
                         del profile_line_copy["lineno"]
                         if not any(profile_line_copy.values()):
                             continue
-                    output["files"][fname_print]["lines"].append(
-                        profile_line
-                    )
+                    output["files"][fname_print]["lines"].append(profile_line)
 
             fn_stats = stats.build_function_stats(fname)
             # Check CPU samples and memory samples.
@@ -424,7 +486,7 @@ class ScaleneJSON:
                         # accumulated; see
                         # ScaleneStatistics.build_function_stats
                         line_no=LineNumber(1),
-                        line=fn_name, # Set the source line to just the function name.
+                        line=fn_name,  # Set the source line to just the function name.
                         stats=fn_stats,
                         profile_this_code=profile_this_code,
                         profile_memory=profile_memory,
