@@ -26,7 +26,7 @@ with contextlib.suppress(Exception):
             # Create a file to hold the supplied code.
             # We encode the cell number in the string for later recovery.
             # The length of the history buffer lets us find the most recent string (this one).
-            filename = f"ipython-input-{len(IPython.get_ipython().history_manager.input_hist_raw)-1}-profile"
+            filename = f"_ipython-input-{len(IPython.get_ipython().history_manager.input_hist_raw)-1}-profile"
             with open(filename, "w+") as tmpfile:
                 tmpfile.write(code)
             args.memory = False  # full Scalene is not yet working, force to not profile memory
@@ -39,24 +39,29 @@ with contextlib.suppress(Exception):
         def scalene(self, line: str, cell: str = "") -> None:
             """%%scalene magic: see https://github.com/plasma-umass/scalene for usage info."""
             if line:
-                sys.argv = ["scalene", *line.split()]
+                sys.argv = ["scalene", "--ipython", *line.split()]
                 (args, _left) = ScaleneParseArgs.parse_args()
+                # print(f"{args=}, {_left=}")
             else:
                 args = ScaleneArguments()
-            if cell:
+                # print(f"{args=}")
+            if args and cell:
                 # Preface with a "\n" to drop the first line (%%scalene).
                 self.run_code(args, "\n" + cell)  # type: ignore
+                # print(f"{cell=}")
 
         @line_magic
         def scrun(self, line: str = "") -> None:
             """%scrun magic: see https://github.com/plasma-umass/scalene for usage info."""
-
+            print("SCRUN MAGIC")
             if line:
-                sys.argv = ["scalene", *line.split()]
+                sys.argv = ["scalene", "--ipython", *line.split()]
                 (args, left) = ScaleneParseArgs.parse_args()
-                self.run_code(args, " ".join(left))  # type: ignore
+                if args:
+                    self.run_code(args, " ".join(left))  # type: ignore
 
     def load_ipython_extension(ip: Any) -> None:
+        print("LOADING")
         ip.register_magics(ScaleneMagics)
         with contextlib.suppress(Exception):
             # For some reason, this isn't loading correctly on the web.
@@ -67,7 +72,7 @@ with contextlib.suppress(Exception):
         print(
             "\n".join(
                 textwrap.wrap(
-                    "Scalene extension successfully loaded. Note: Scalene currently only supports CPU+GPU profiling inside Jupyter notebooks. For full Scalene profiling, use the command line version."
+                    "Scalene extension successfully loaded. Note: Scalene currently only supports CPU+GPU profiling inside Jupyter notebooks. For full Scalene profiling, use the command line version. To profile in line mode, use `%scrun [options] statement`. To profile in cell mode, use `%%scalene [options]` followed by your code."
                 )
             )
         )
