@@ -5,7 +5,7 @@ import tempfile
 from collections import OrderedDict, defaultdict
 from operator import itemgetter
 from pathlib import Path
-from typing import Any, Callable, Dict, List, Union
+from typing import Any, Callable, Dict, List, Optional, Union
 
 from rich import box
 from rich.console import Console
@@ -102,7 +102,7 @@ class ScaleneOutput:
             fname=fname,
             fname_print=fname,
             line_no=line_no,
-            line=line,
+            line=str(line),
             stats=stats,
             profile_this_code=profile_this_code,
             force_print=force_print,
@@ -306,7 +306,8 @@ class ScaleneOutput:
         pid: int,
         profile_this_code: Callable[[Filename, LineNumber], bool],
         python_alias_dir: Path,
-        program_path: Path,
+        program_path: Filename,
+        program_args: Optional[List[str]],
         profile_memory: bool = True,
         reduced_profile: bool = False,
     ) -> bool:
@@ -420,7 +421,7 @@ class ScaleneOutput:
             fname_print = fname
             import re
 
-            if result := re.match("ipython-input-([0-9]+)-.*", fname_print):
+            if result := re.match("_ipython-input-([0-9]+)-.*", fname_print):
                 fname_print = Filename(f"[{result.group(1)}]")
 
             # Print header.
