@@ -1,14 +1,15 @@
 import argparse
 import contextlib
-import platform
+import os
 import sys
 from textwrap import dedent
 from typing import Any, List, NoReturn, Optional, Tuple
 
+from scalene.find_browser import find_browser
 from scalene.scalene_arguments import ScaleneArguments
 from scalene.scalene_version import scalene_version, scalene_date
 
-scalene_gui_url = "https://plasma-umass.org/scalene-gui/"
+scalene_gui_url = f'file:{os.path.join(os.path.dirname(__file__), "scalene-gui", "index.html")}'
 
 
 class RichArgParser(argparse.ArgumentParser):
@@ -47,7 +48,7 @@ class ScaleneParseArgs:
                 sys._exit = ScaleneParseArgs.clean_exit  # type: ignore
         defaults = ScaleneArguments()
         usage = dedent(
-            f"""[b]Scalene[/b]: a high-precision CPU and memory profiler, version {scalene_version} ({scalene_date})
+            rf"""[b]Scalene[/b]: a high-precision CPU and memory profiler, version {scalene_version} ({scalene_date})
 [link=https://github.com/plasma-umass/scalene]https://github.com/plasma-umass/scalene[/link]
 
 
@@ -134,6 +135,14 @@ for the process ID that Scalene reports. For example:
             default=defaults.cli,
             help="forces use of the command-line",
         )
+        parser.add_argument(
+            "--stacks",
+            dest="stacks",
+            action="store_const",
+            const=True,
+            default=defaults.stacks,
+            help="collect stack traces",
+        )
         parser.add_argument(
             "--web",
             dest="web",
@@ -142,13 +151,21 @@ for the process ID that Scalene reports. For example:
             default=defaults.web,
             help="opens a web tab to view the profile (saved as 'profile.html')",
         )
+        parser.add_argument(
+            "--no-browser",
+            dest="no_browser",
+            action="store_const",
+            const=True,
+            default=defaults.no_browser,
+            help="doesn't open a web tab; just saves the profile ('profile.html')",
+        )
         parser.add_argument(
             "--viewer",
             dest="viewer",
             action="store_const",
             const=True,
             default=False,
-            help=f"only opens the web UI ({scalene_gui_url})",
+            help=f"opens the Scalene web UI and exits.",
         )
         parser.add_argument(
             "--reduced-profile",
@@ -190,15 +207,23 @@ for the process ID that Scalene reports. For example:
             + (str(defaults.gpu))
             + " [/blue])",
         )
+        if sys.platform == "win32":
+            memory_profile_message = (
+                "profile memory (not supported on this platform)"
+            )
+        else:
+            memory_profile_message = (
+                "profile memory (default: [blue]"
+                + (str(defaults.memory))
+                + " [/blue])"
+            )
         parser.add_argument(
             "--memory",
             dest="memory",
             action="store_const",
             const=True,
             default=None,
-            help="profile memory (default: [blue]"
-            + (str(defaults.memory))
-            + " [/blue])",
+            help=memory_profile_message,
         )
         parser.add_argument(
             "--profile-all",
@@ -293,7 +318,14 @@ for the process ID that Scalene reports. For example:
             + (str(defaults.memory_leak_detector))
             + "[/blue])",
         )
-
+        parser.add_argument(
+            "--ipython",
+            dest="ipython",
+            action="store_const",
+            const=True,
+            default=False,
+            help=argparse.SUPPRESS,
+        )
         if sys.platform != "win32":
             # Turning profiling on and off from another process is currently not supported on Windows.
             group = parser.add_mutually_exclusive_group(required=False)
@@ -305,10 +337,10 @@ for the process ID that Scalene reports. For example:
             group.add_argument(
                 "--off", action="store_true", help="start with profiling off"
             )
-            # the PID of the profiling process (for internal use only)
-            parser.add_argument(
-                "--pid", type=int, default=0, help=argparse.SUPPRESS
-            )
+        # the PID of the profiling process (for internal use only)
+        parser.add_argument(
+            "--pid", type=int, default=0, help=argparse.SUPPRESS
+        )
         # collect all arguments after "---", which Scalene will ignore
         parser.add_argument(
             "---",
@@ -320,6 +352,7 @@ for the process ID that Scalene reports. For example:
         # Parse out all Scalene arguments.
         # https://stackoverflow.com/questions/35733262/is-there-any-way-to-instruct-argparse-python-2-7-to-remove-found-arguments-fro
         args, left = parser.parse_known_args()
+
         # Hack to simplify functionality for Windows platforms.
         if sys.platform == "win32":
             args.on = True
@@ -329,13 +362,8 @@ for the process ID that Scalene reports. For example:
 
         # Launch the UI if `--viewer` was selected.
         if args.viewer:
-            import webbrowser
-
-            if (
-                webbrowser.get()
-                and type(webbrowser.get()).__name__ != "GenericBrowser"
-            ):
-                webbrowser.open(scalene_gui_url)
+            if browser := find_browser():
+                browser.open(scalene_gui_url)
             else:
                 print(f"Scalene: could not open {scalene_gui_url}.")
             sys.exit(0)
@@ -356,7 +384,7 @@ for the process ID that Scalene reports. For example:
         args.cpu = True  # Always true
 
         in_jupyter_notebook = len(sys.argv) >= 1 and re.match(
-            r"ipython-input-([0-9]+)-.*", sys.argv[0]
+            r"_ipython-input-([0-9]+)-.*", sys.argv[0]
         )
         # If the user did not enter any commands (just `scalene` or `python3 -m scalene`),
         # print the usage information and bail.
@@ -365,5 +393,13 @@ for the process ID that Scalene reports. For example:
             sys.exit(-1)
         if args.version:
             print(f"Scalene version {scalene_version} ({scalene_date})")
-            sys.exit(-1)
+            if not args.ipython:
+                sys.exit(-1)
+            # Clear out the namespace. We do this to indicate that we should not run further in IPython.
+            for arg in list(args.__dict__):
+                delattr(args, arg)
+            # was:
+            # args = (
+            #     []
+            # )  # We use this to indicate that we should not run further in IPython.
         return args, left
