@@ -17,7 +17,6 @@ from typing import (
 
 import cloudpickle
 
-# from scalene.adaptive import Adaptive
 from scalene.runningstats import RunningStats
 
 Address = NewType("Address", str)
@@ -40,6 +39,9 @@ class ScaleneStatistics:
         # total allocation samples taken
         self.alloc_samples: int = 0
 
+        #  full stacks taken during CPU samples, together with number of hits
+        self.stacks: Dict[Tuple[Any], int] = defaultdict(int)
+
         #   CPU samples for each location in the program
         #   spent in the interpreter
         self.cpu_samples_python: Dict[
@@ -67,6 +69,11 @@ class ScaleneStatistics:
             Filename, Dict[LineNumber, RunningStats]
         ] = defaultdict(lambda: defaultdict(RunningStats))
 
+        # Running stats for core utilization.
+        self.core_utilization: Dict[
+            Filename, Dict[LineNumber, RunningStats]
+        ] = defaultdict(lambda: defaultdict(RunningStats))
+
         # Running count of total CPU samples per file. Used to prune reporting.
         self.cpu_samples: Dict[Filename, float] = defaultdict(float)
 
@@ -183,9 +190,11 @@ class ScaleneStatistics:
         self.start_time = 0
         self.elapsed_time = 0
         self.alloc_samples = 0
+        self.stacks.clear()
         self.cpu_samples_python.clear()
         self.cpu_samples_c.clear()
         self.cpu_utilization.clear()
+        self.core_utilization.clear()
         self.cpu_samples.clear()
         self.gpu_samples.clear()
         self.malloc_samples.clear()
@@ -264,6 +273,9 @@ class ScaleneStatistics:
             fn_stats.cpu_utilization[fn_name][
                 first_line_no
             ] += self.cpu_utilization[filename][line_no]
+            fn_stats.core_utilization[fn_name][
+                first_line_no
+            ] += self.core_utilization[filename][line_no]
             fn_stats.per_line_footprint_samples[fn_name][
                 first_line_no
             ] += self.per_line_footprint_samples[filename][line_no]
@@ -310,12 +322,14 @@ class ScaleneStatistics:
         "current_footprint",
         "elapsed_time",
         "alloc_samples",
+        "stacks",
         "total_cpu_samples",
         "cpu_samples_c",
         "cpu_samples_python",
         "bytei_map",
         "cpu_samples",
         "cpu_utilization",
+        "core_utilization",
         "memory_malloc_samples",
         "memory_python_samples",
         "memory_free_samples",
@@ -368,16 +382,30 @@ class ScaleneStatistics:
             for lineno in src[filename]:
                 dest[filename][lineno] += src[filename][lineno]
 
+    @staticmethod
+    def increment_core_utilization(
+        dest: Dict[Filename, Dict[LineNumber, RunningStats]],
+        src: Dict[Filename, Dict[LineNumber, RunningStats]],
+    ) -> None:
+        """Increment core utilization."""
+        for filename in src:
+            for lineno in src[filename]:
+                dest[filename][lineno] += src[filename][lineno]
+
     def merge_stats(self, the_dir_name: pathlib.Path) -> None:
         """Merge all statistics in a given directory."""
         the_dir = pathlib.Path(the_dir_name)
-        for f in list(the_dir.glob("**/scalene*")):
+        for f in list(the_dir.glob(os.path.join("**", "scalene*"))):
             # Skip empty files.
             if os.path.getsize(f) == 0:
                 continue
             with open(f, "rb") as file:
                 unpickler = pickle.Unpickler(file)
-                value = unpickler.load()
+                try:
+                    value = unpickler.load()
+                except EOFError:
+                    # Empty file for some reason.
+                    continue
                 x = ScaleneStatistics()
                 for i, n in enumerate(ScaleneStatistics.payload_contents):
                     setattr(x, n, value[i])
@@ -390,8 +418,12 @@ class ScaleneStatistics:
                 self.increment_cpu_utilization(
                     self.cpu_utilization, x.cpu_utilization
                 )
+                self.increment_core_utilization(
+                    self.core_utilization, x.core_utilization
+                )
                 self.elapsed_time = max(self.elapsed_time, x.elapsed_time)
                 self.alloc_samples += x.alloc_samples
+                self.stacks.update(x.stacks)
                 self.total_cpu_samples += x.total_cpu_samples
                 self.total_gpu_samples += x.total_gpu_samples
                 self.increment_per_line_samples(
@@ -414,7 +446,9 @@ class ScaleneStatistics:
                 # is sent between processes. Samples are in the format [time, footprint]
                 for filename in self.per_line_footprint_samples:
                     for lineno in self.per_line_footprint_samples[filename]:
-                        self.per_line_footprint_samples[filename][lineno].sort(key=lambda x : x[0])
+                        self.per_line_footprint_samples[filename][lineno].sort(
+                            key=lambda x: x[0]
+                        )
                 self.increment_per_line_samples(
                     self.memory_malloc_count, x.memory_malloc_count
                 )
@@ -445,9 +479,9 @@ class ScaleneStatistics:
                     x.total_memory_malloc_samples
                 )
                 self.memory_footprint_samples += x.memory_footprint_samples
-                # Sorting footprint samples by time when sample was taken. 
+                # Sorting footprint samples by time when sample was taken.
                 # Samples are in the format [time, footprint]
-                self.memory_footprint_samples.sort(key=lambda x : x[0])
+                self.memory_footprint_samples.sort(key=lambda x: x[0])
                 for k, val in x.function_map.items():
                     if k in self.function_map:
                         self.function_map[k].update(val)
