@@ -1,7 +1,7 @@
+from typing import Any, Iterator, List
+
 from rich.console import Console
 from rich.segment import Segment
-from rich.style import Style
-from typing import Any, Iterator, List
 
 
 class SyntaxLine:
@@ -9,6 +9,6 @@ class SyntaxLine:
         self.segments = segments
 
     def __rich_console__(
-        self, console: Console, options: Any
+        self, console: Console, _options: Any
     ) -> Iterator[Segment]:
         yield from self.segments
