@@ -1,4 +1,5 @@
 #include "pywhere.hpp"
+#include "traceconfig.hpp"
 
 #include <Python.h>
 #include <dlfcn.h>
@@ -16,126 +17,6 @@
 //
 // #include "printf.h"
 const int NEWLINE_TRIGGER_LENGTH = 98820;
-class TraceConfig {
- public:
-  TraceConfig(PyObject* list_wrapper, PyObject* base_path, bool profile_all_b) {
-    // Assumes that each item is a bytes object
-    owner = list_wrapper;
-    path_owner = base_path;
-    Py_IncRef(owner);
-    Py_IncRef(path_owner);
-    profile_all = profile_all_b;
-    auto size = PyList_Size(owner);
-    items.reserve(size);
-    for (int i = 0; i < size; i++) {
-      auto item = PyList_GetItem(owner, i);
-      auto unic = PyUnicode_AsASCIIString(item);
-      auto s = PyBytes_AsString(unic);
-      items.push_back(s);
-    }
-    scalene_base_path = PyBytes_AsString(PyUnicode_AsASCIIString(base_path));
-  }
-
-  bool should_trace(char* filename) {
-    auto res = _memoize.find(filename);
-    if ( res != _memoize.end()) {
-      return res->second;
-    }
-    // Return false if filename contains paths corresponding to the native Python libraries.
-    // This is to avoid profiling the Python interpreter itself.
-    // Also exclude site-packages and any IPython files.
-
-#if defined(_WIN32)
-    // If on Windows, use \\ as the path separator.
-    const auto PATH_SEP = "\\";
-#else
-    // Assume all others are POSIX.
-    const auto PATH_SEP = "/";
-#endif
-
-    auto python_lib = std::string("lib") + std::string(PATH_SEP) + std::string("python");
-    auto scalene_lib = std::string("scalene") + std::string(PATH_SEP) + std::string("scalene");
-    auto anaconda_lib = std::string("anaconda3") + std::string(PATH_SEP) + std::string("lib");
-
-    if (strstr(filename, python_lib.c_str()) != nullptr ||
-        strstr(filename, scalene_lib.c_str()) != nullptr ||
-        strstr(filename, anaconda_lib.c_str()) != nullptr ||
-        strstr(filename, "site-packages") != nullptr ||
-        (*filename == '<' && strstr(filename, "<ipython") != nullptr)) {
-      _memoize.insert(std::pair<std::string, bool>(std::string(filename), false));
-      return false;
-    }
-
-    if (owner != nullptr) {
-      for (char* traceable : items) {
-        if (strstr(filename, traceable)) {
-          _memoize.insert(std::pair<std::string, bool>(std::string(filename), true));
-          return true;
-        }
-      }
-    }
-
-    // Temporarily change the current working directory to the original program
-    // path.
-    char original_cwd_buf[PATH_MAX];
-#ifdef _WIN32
-    auto oldcwd = _getcwd(original_cwd_buf, PATH_MAX);
-#else
-    auto oldcwd = getcwd(original_cwd_buf, PATH_MAX);
-#endif
-    chdir(scalene_base_path);
-    char resolved_path[PATH_MAX];
-
-    // Check to see if the file we are profiling is in the original path.
-    bool did_resolve_path = realpath(filename, resolved_path);
-    bool result = false;
-    if (did_resolve_path) {
-      // True if we found this file in the original path.
-      result = (strstr(resolved_path, scalene_base_path) != nullptr);
-    }
-
-    // Now change back to the original current working directory.
-    chdir(oldcwd);
-    _memoize.insert(std::pair<std::string, bool>(std::string(filename), result));
-    return result;
-  }
-
-  void print() {
-    printf("Profile all? %d\nitems {", profile_all);
-    for (auto c : items) {
-      printf("\t%s\n", c);
-    }
-    printf("}\n");
-  }
-
-  static void setInstance(TraceConfig* instance) {
-    std::lock_guard<decltype(_instanceMutex)> g(_instanceMutex);
-    delete _instance;
-    _instance = instance;
-  }
-
-  static TraceConfig* getInstance() {
-    std::lock_guard<decltype(_instanceMutex)> g(_instanceMutex);
-    return _instance;
-  }
-
- private:
-  std::vector<char*> items;
-  char* scalene_base_path;
-  // This is to keep the object in scope so that
-  // the data pointers are always valid
-  PyObject* owner;
-  PyObject* path_owner;
-  bool profile_all;
-
-  static std::mutex _instanceMutex;
-  static TraceConfig* _instance;
-  static std::unordered_map<std::string, bool> _memoize;
-};
-
-TraceConfig* TraceConfig::_instance = 0;
-std::mutex TraceConfig::_instanceMutex;
-std::unordered_map<std::string, bool> TraceConfig::_memoize;
 
 static bool last_profiled_invalidated = false;
 // An RAII class to simplify acquiring and releasing the GIL.
@@ -227,11 +108,33 @@ PyObject* set_last_profiled_invalidated_true(PyObject* self, PyObject* args) {
   Py_RETURN_NONE;
 }
 
-
 PyObject* set_last_profiled_invalidated_false(PyObject* self, PyObject* args) {
   last_profiled_invalidated = false;
   Py_RETURN_NONE;
 }
+
+
+PyObject* set_scalene_done_true(PyObject* self, PyObject* args) {
+    auto scalene_done =
+      (std::atomic_bool*)dlsym(RTLD_DEFAULT, "p_scalene_done");
+    if (scalene_done == nullptr) {
+      PyErr_SetString(PyExc_Exception, "Unable to find p_scalene_done");
+      return NULL;
+    }
+  *scalene_done = true;
+  Py_RETURN_NONE;
+}
+PyObject* set_scalene_done_false(PyObject* self, PyObject* args) {
+    auto scalene_done =
+      (std::atomic_bool*)dlsym(RTLD_DEFAULT, "p_scalene_done");
+    if (scalene_done == nullptr) {
+      PyErr_SetString(PyExc_Exception, "Unable to find p_whereInPython");
+      return NULL;
+    }
+  *scalene_done = false;
+  Py_RETURN_NONE;
+}
+
 int whereInPython(std::string& filename, int& lineno, int& bytei) {
   if (!Py_IsInitialized()) {  // No python, no python stack.
     return 0;
@@ -267,6 +170,7 @@ int whereInPython(std::string& filename, int& lineno, int& bytei) {
         PyFrame_GetCode(static_cast<PyFrameObject*>(frame));
     PyPtr<> co_filename =
         PyUnicode_AsASCIIString(static_cast<PyCodeObject*>(code)->co_filename);
+    
     if (!(static_cast<PyObject*>(co_filename))) {
       return 0;
     }
@@ -276,22 +180,20 @@ int whereInPython(std::string& filename, int& lineno, int& bytei) {
       continue;
     }
 
-    if (!strstr(filenameStr, "<") && !strstr(filenameStr, "/python") &&
-        !strstr(filenameStr, "scalene/scalene")) {
-      if (traceConfig->should_trace(filenameStr)) {
-#if defined(PyPy_FatalError)
-        // If this macro is defined, we are compiling PyPy, which
-        // AFAICT does not have any way to access bytecode index, so
-        // we punt and set it to 0.
-        bytei = 0;
-#else
-        bytei = PyFrame_GetLasti(static_cast<PyFrameObject*>(frame));
-#endif
-        lineno = PyFrame_GetLineNumber(static_cast<PyFrameObject*>(frame));
+    if (traceConfig->should_trace(filenameStr)) {
 
-        filename = filenameStr;
-        return 1;
-      }
+#if defined(PyPy_FatalError)
+      // If this macro is defined, we are compiling PyPy, which
+      // AFAICT does not have any way to access bytecode index, so
+      // we punt and set it to 0.
+      bytei = 0;
+#else
+      bytei = PyFrame_GetLasti(static_cast<PyFrameObject*>(frame));
+#endif
+      lineno = PyFrame_GetLineNumber(static_cast<PyFrameObject*>(frame));
+      
+      filename = filenameStr;
+      return 1;
     }
 
     frame = PyFrame_GetBack(static_cast<PyFrameObject*>(frame));
@@ -488,6 +390,10 @@ static PyMethodDef EmbMethods[] = {
     {"get_last_profiled_invalidated", get_last_profiled_invalidated, METH_NOARGS, ""},
     {"set_last_profiled_invalidated_true", set_last_profiled_invalidated_true, METH_NOARGS, ""},
     {"set_last_profiled_invalidated_false", set_last_profiled_invalidated_false, METH_NOARGS, ""},
+    {"set_scalene_done_true", set_scalene_done_true, METH_NOARGS, ""},
+    {"set_scalene_done_false", set_scalene_done_false, METH_NOARGS, ""},
+
+
     {NULL, NULL, 0, NULL}};
 
 static PyModuleDef EmbedModule = {PyModuleDef_HEAD_INIT,
